Skip to main content
summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorKai Maetzel2004-11-18 10:56:08 +0000
committerKai Maetzel2004-11-18 10:56:08 +0000
commitf677493b7ff347be10eb559236afd2551ccf5641 (patch)
treebca60e02c32b3d28c86cc2b5a9ef7704a4c72bc5 /org.eclipse.text/projection
parentdb839fd2af7049a3229226c584b72c7a45b767d1 (diff)
downloadeclipse.platform.text-f677493b7ff347be10eb559236afd2551ccf5641.tar.gz
eclipse.platform.text-f677493b7ff347be10eb559236afd2551ccf5641.tar.xz
eclipse.platform.text-f677493b7ff347be10eb559236afd2551ccf5641.zip
code cleanup - getting rid of warnings
Diffstat (limited to 'org.eclipse.text/projection')
-rw-r--r--org.eclipse.text/projection/org/eclipse/jface/text/projection/ChildDocument.java18
-rw-r--r--org.eclipse.text/projection/org/eclipse/jface/text/projection/IMinimalMapping.java10
-rw-r--r--org.eclipse.text/projection/org/eclipse/jface/text/projection/ProjectionDocument.java8
3 files changed, 18 insertions, 18 deletions
diff --git a/org.eclipse.text/projection/org/eclipse/jface/text/projection/IMinimalMapping.java b/org.eclipse.text/projection/org/eclipse/jface/text/projection/IMinimalMapping.java
index a0a89831945..41d076ec20e 100644
--- a/org.eclipse.text/projection/org/eclipse/jface/text/projection/IMinimalMapping.java
+++ b/org.eclipse.text/projection/org/eclipse/jface/text/projection/IMinimalMapping.java
@@ -25,27 +25,27 @@ import org.eclipse.jface.text.IRegion;
*/
interface IMinimalMapping {
- /**
+ /*
* @see org.eclipse.jface.text.IDocumentInformationMapping#getCoverage()
*/
IRegion getCoverage();
- /**
+ /*
* @see org.eclipse.jface.text.IDocumentInformationMapping#toOriginRegion(IRegion)
*/
IRegion toOriginRegion(IRegion region) throws BadLocationException;
- /**
+ /*
* @see org.eclipse.jface.text.IDocumentInformationMapping#toOriginOffset(int)
*/
int toOriginOffset(int offset) throws BadLocationException;
- /**
+ /*
* @see org.eclipse.jface.text.IDocumentInformationMappingExtension#toExactOriginRegions(IRegion)
*/
IRegion[] toExactOriginRegions(IRegion region)throws BadLocationException;
- /**
+ /*
* @see org.eclipse.jface.text.IDocumentInformationMappingExtension#getImageLength()
*/
int getImageLength();
diff --git a/org.eclipse.text/projection/org/eclipse/jface/text/projection/ProjectionDocument.java b/org.eclipse.text/projection/org/eclipse/jface/text/projection/ProjectionDocument.java
index 99286a1fe72..83fc2c2853e 100644
--- a/org.eclipse.text/projection/org/eclipse/jface/text/projection/ProjectionDocument.java
+++ b/org.eclipse.text/projection/org/eclipse/jface/text/projection/ProjectionDocument.java
@@ -589,11 +589,11 @@ public class ProjectionDocument extends AbstractDocument {
if (imageRegion != null)
return new ProjectionDocumentEvent(this, imageRegion.getOffset(), imageRegion.getLength(), masterEvent.getText(), masterEvent);
return null;
- } else {
- ProjectionDocumentEvent event= new ProjectionDocumentEvent(this, fOriginalEvent.getOffset(), fOriginalEvent.getLength(), fOriginalEvent.getText(), masterEvent);
- fOriginalEvent= null;
- return event;
}
+
+ ProjectionDocumentEvent event= new ProjectionDocumentEvent(this, fOriginalEvent.getOffset(), fOriginalEvent.getLength(), fOriginalEvent.getText(), masterEvent);
+ fOriginalEvent= null;
+ return event;
}
private boolean includes(IRegion region, int offset) {

Back to the top
diff --git a/org.eclipse.text/projection/org/eclipse/jface/text/projection/ChildDocument.java b/org.eclipse.text/projection/org/eclipse/jface/text/projection/ChildDocument.java
index dfd775d32ae..fbd9173978a 100644
--- a/org.eclipse.text/projection/org/eclipse/jface/text/projection/ChildDocument.java
+++ b/org.eclipse.text/projection/org/eclipse/jface/text/projection/ChildDocument.java
@@ -35,22 +35,22 @@ public class ChildDocument extends ProjectionDocument {
/**
* Creates a new visible region.
*
* @param offset the offset of the region
* @param length the length of the region
*/
- public VisibleRegion(int offset, int length) {
- super(offset, length);
+ public VisibleRegion(int regionOffset, int regionLength) {
+ super(regionOffset, regionLength);
}
/**
* If offset is the end of the visible region and the length is 0,
* the offset is considered overlapping with the visible region.
*
* @see org.eclipse.jface.text.Position#overlapsWith(int, int)
*/
- public boolean overlapsWith(int offset, int length) {
- boolean appending= (offset == this.offset + this.length) && length == 0;
- return appending || super.overlapsWith(offset, length);
+ public boolean overlapsWith(int regionOffset, int regionLength) {
+ boolean appending= (regionOffset == offset + length) && regionLength == 0;
+ return appending || super.overlapsWith(regionOffset, regionLength);
}
}
@@ -35,22 +35,22 @@ public class ChildDocument extends ProjectionDocument {
* Creates a new visible region.
*
- * @param offset the offset of the region
- * @param length the length of the region
+ * @param regionOffset the offset of the region
+ * @param regionLength the length of the region
*/
@@ -35,22 +35,22 @@ public class ChildDocument extends ProjectionDocument {
}
/**
- * If offset is the end of the visible region and the length is 0,
- * the offset is considered overlapping with the visible region.
+ * If <code>regionOffset</code> is the end of the visible region and the <code>regionLength == 0</code>,
+ * the <code>regionOffset</code> is considered overlapping with the visible region.
*
* @see org.eclipse.jface.text.Position#overlapsWith(int, int)